/*********************************************
*
* PROJEKT: CC1101;
*
* Chip type	      : ATmega16
* Clock frequency     : 8.000.000Hz
* Autor: Muris Pucic Trax (www.elektronika.ba)
*
*********************************************/

#include <stdio.h>
#include <avr/io.h>
#include <stdlib.h>
#include <string.h>
#include <avr/iom16.h>

#include "pauza.h"
#include "mega16.h"
#include "uart.h"
#include "cc1101.h"
#include "MyModem2.h"

//#define               PREDAJNIK 1 // if defined, FW is for the transmitter

/*****
	MAIN program
*****/
int
main( void )
{
  unsigned char temp[30], r[4];
  char          i;

  uint8_t       rssi_dec;
  int16_t       rssi_dBm;
  uint8_t       rssi_offset = 74;	// CC1101 at 868/900 MHz

  ATMEGA_Init(  );

  PORTC |= ( 1 << LED1 );	// =1

  uart_puts( "ccxxx0_PowerOnReset\r\n" );
  ccxxx0_PowerOnReset(  );
  uart_puts( "ccxxx0_Setup\r\n" );
  ccxxx0_Setup( &rfSettings );

  PORTC &= ~( 1 << LED1 );	// =0

#ifdef PREDAJNIK
  // override setup za tx
  // ccxxx0_Write(CCxxx0_IOCFG0, 0x2F); // PA_PD .. neki klinac :)

  while ( 1 )
  {
    ccxxx0_Strobe( CCxxx0_SIDLE );
    ccxxx0_WriteBurst( CCxxx0_PATABLE, &paTable[0], 1 );	// max power
    delay_ms( 1 );
    ccxxx0_Strobe( CCxxx0_SFTX );	// flush tx buff
    delay_ms( 1 );
    ccxxx0_WriteBurst( CCxxx0_TXFIFO, "Mabcd", 5 );	// addr=M, payload=4
							// bytes, ukupno
							// PKTLEN=5

    PORTB &= ~( 1 << PAN );	// enable power amp
    PORTC |= ( 1 << LED3 );	// pali tx led
    delay_ms( 1 );		// da se PA malo probudi (1uS)
    ccxxx0_Strobe( CCxxx0_STX );	// activate tx!

    // Kad zavrsi sa emitovanjem, ugasi PA
    /*
     * i=1; while(i==1) { j = ccxxx0_Strobe(CCxxx0_SNOP); // da pokupimo
     * status byte // ako je bit 5=0 to znaci da vise ne emitujemo, pa mozemo 
     * izaci iz petlje if( !(j & (1 << 5)) ) i=0; } 
     */
    /*
     * for(i=0;i<250;i++) { //if( PINB&(1 << CC_GDO0) ) PORTC &= ~(1 <<
     * LED1); //pali //if( !( PINB&(1 << CC_GDO0) ) ) PORTC |= (1 << LED1);
     * //gasi delay_ms(1); } 
     */
    delay_ms( 120 );

    PORTC &= ~( 1 << LED3 );	// gasi tx led
    PORTB |= ( 1 << PAN );	// disable power amp

    ccxxx0_Strobe( CCxxx0_SIDLE );
    delay_ms( 200 );
  }
#else
  PORTB |= ( 1 << PAN );	// disable power amp

  ccxxx0_Strobe( CCxxx0_SIDLE );
  ccxxx0_Strobe( CCxxx0_SFRX );

  ccxxx0_Strobe( CCxxx0_SRX );

  while ( 1 )
  {
    // Ako ima paket za nas
    if ( PINB & ( 1 << CC_GDO0 ) )
    {
      PORTC |= ( 1 << LED4 );	// pali nesto doslo led

      ccxxx0_Strobe( CCxxx0_SIDLE );
      i = ccxxx0_Read( CCxxx0_RXBYTES );

      uart_puts( "RXed bytes: " );
      uart_putc( ( i + 48 ) );
      uart_puts( "\r\n" );

      ccxxx0_ReadBurst( CCxxx0_RXFIFO, temp, i );

      uart_puts( "RXed data: " );
      uart_putsn( temp, ( i - 2 ) );	// nemoj LQI i RSSI
      uart_puts( "\r\n" );

      uart_puts( "RSSI: " );
      rssi_dec = temp[i - 2];
      if ( rssi_dec >= 128 )
	rssi_dBm =
	    ( int16_t ) ( ( int16_t ) ( rssi_dec - 256 ) / 2 ) - rssi_offset;
      else
	rssi_dBm = ( rssi_dec / 2 ) - rssi_offset;

      PORTA = ( rssi_dBm * ( -1 ) );	// i na diode jebat ga :)

      itoa( rssi_dBm, r, 10 );
      uart_puts( r );
      uart_puts( "dBm, LQI: " );
      itoa( temp[i - 1], r, 10 );
      uart_puts( r );
      uart_puts( "\r\n" );

      // Flushaj RX buffer
      ccxxx0_Strobe( CCxxx0_SIDLE );
      ccxxx0_Strobe( CCxxx0_SFRX );
      // Pali nazad RX
      ccxxx0_Strobe( CCxxx0_SRX );

      PORTC &= ~( 1 << LED4 );	// gasi nesto doslo led
    }
  }
#endif

  // LOOP HERE FOREVER .. if we ever come here :)
  while ( 1 )
  {
    asm( "nop" );
  }

  return 0;
}
