/*********************************************
* uart.c - source fajl
* Rad sa UART-om
* Autor: Muris Pucic Trax (www.elektronika.ba)
*********************************************/

#include <avr/io.h>

#include "mega16.h"

/*****
	Salje karakter/byte.
*****/
void
uart_putc( unsigned char c )
{
  // wait until UDR ready
  while ( !( UCSRA & ( 1 << UDRE ) ) ) ;
  UDR = c;			// send character
}

/*****
	Salje string do kraja (null-terminated string).
*****/
void
uart_puts( unsigned char *s )
{
  PORTC |= ( 1 << LED2 );	// =1
  // loop until *s != NULL
  while ( *s )
  {
    uart_putc( *s );
    s++;
  }
  PORTC &= ~( 1 << LED2 );	// =0
}

/*****
	Salje string, n komada (NE null-terminated string).
*****/
void
uart_putsn( unsigned char *s, unsigned char n )
{
  PORTC |= ( 1 << LED2 );	// =1
  // loop until *s != NULL
  while ( n > 0 )
  {
    uart_putc( *s );
    s++;
    n--;
  }
  PORTC &= ~( 1 << LED2 );	// =0
}

/*****
	Prima bajt sa UART-a.
*****/
unsigned char
uart_getc( void )
{
  unsigned char ReceivedByte;

  PORTC |= ( 1 << LED2 );	// =1
  while ( ( UCSRA & ( 1 << RXC ) ) == 0 )
  {
  };				// Do nothing until data have been recieved
				// and is ready to be read from UDR
  ReceivedByte = UDR;		// Fetch the recieved byte value into the
				// variable "ByteReceived"
  PORTC &= ~( 1 << LED2 );	// =0
  return ( ReceivedByte );
}
